@@ -24,6 +24,8 @@ import (
 	"testing"
 	"time"
 
+	"github.com/aws/aws-sdk-go/aws/credentials"
+	"github.com/aws/aws-sdk-go/aws/signer/v4"
 	"github.com/aws/aws-sdk-go/service/kms/kmsiface"
 	communicatorMocks "github.com/aws/session-manager-plugin/src/communicator/mocks"
 	"github.com/aws/session-manager-plugin/src/config"
@@ -58,6 +60,8 @@ var (
 	payload                                     = []byte("testPayload")
 	streamDataSequenceNumber                    = int64(0)
 	expectedSequenceNumber                      = int64(0)
+	region                                      = "us-east-1"
+	mockSigner                                  = &v4.Signer{Credentials: credentials.NewStaticCredentials("AKID", "SECRET", "SESSION")}
 )
 
 func TestInitialize(t *testing.T) {
@@ -82,9 +86,9 @@ func TestSetWebsocket(t *testing.T) {
 
 	mockWsChannel.On("GetStreamUrl").Return(streamUrl)
 	mockWsChannel.On("GetChannelToken").Return(channelToken)
-	mockWsChannel.On("Initialize", mock.Anything, mock.Anything, mock.Anything).Return(nil)
+	mockWsChannel.On("Initialize", mock.Anything, mock.Anything, mock.Anything, mock.Anything, mock.Anything).Return(nil)
 
-	datachannel.SetWebsocket(mockLogger, streamUrl, channelToken)
+	datachannel.SetWebsocket(mockLogger, streamUrl, channelToken, region, mockSigner)
 
 	assert.Equal(t, streamUrl, datachannel.wsChannel.GetStreamUrl())
 	assert.Equal(t, channelToken, datachannel.wsChannel.GetChannelToken())
